<?php
/**
 * @file
 * Smartmenus theme fnctions.
 */

/**
 * Theme function definition.
 */
function theme_smartmenus_menu($variables = array()) {
  // Build the menu.
  $tree = $variables['tree'];

  // Create menu attributes.
  $attributes = array (
    'id' => $variables['attributes']['id'],
    'class' => $class = implode(' ', array_filter($variables['attributes']['class'])),
  );

  // Recursively build menu outpout.
  $output = smartmenus_menu_tree_output($tree, $attributes);

  return drupal_render($output);
}

/**
 * Render menu tree ouput with
 * additional formatting.
 */
function smartmenus_menu_tree_output($tree, $attributes = NULL) {
  $items = array();
  foreach ($tree as $data) {
    if ($data['link']['access'] && !$data['link']['hidden']) {
      $items[] = $data;
    }
  }

  $build = array();
  $num_items = count($items);
  foreach ($items as $i => $item) {
    $class = array();

    if ($i == 0) {
      $class[] = 'first';
    }
    if ($i == $num_items - 1) {
      $class[] = 'last';
    }

    // Build link.
    $element['#theme'] = 'menu_link__' . strtr($item['link']['menu_name'], '-', '_');
    $element['#attributes']['class'] = $class;
    $element['#title'] = $item['link']['title'];
    $element['#href'] = $item['link']['href'];
    $element['#localized_options'] = !empty($item['link']['localized_options']) ? $item['link']['localized_options'] : array();
    $element['#original_link'] = $item['link'];

    // Recursively build menu output.
    if ($item['below']) {
      $element['#below'] = smartmenus_menu_tree_output($item['below']);
    } else {
      $element['#below'] = array();
    }

    // Return expected menu array.
    $build[$item['link']['mlid']] = $element;
  }

  if ($build) {
    // Implement own menu wrapper.
    $output['#sorted'] = TRUE;
    $output['#tree'] = $build;
    $output['#attributes'] = $attributes;
    $output['#theme_wrappers'][] = 'smartmenus_menu_tree';
  }

  return $output;
}

/**
 * Implements theme_smartmenus_menu_tree().
 */
function theme_smartmenus_menu_tree($variables) {
  if (!empty($variables['attributes'])) {
    $id = $variables['attributes']['id'];
    $class = $variables['attributes']['class'];

    //$output  = '<div class="menu-button">' . t('Menu') . '</div>';
    $output = '<ul id="' . $id . '" class="' . $class . '">' . drupal_render($variables['tree']) . '</ul>';
  }
  else {
    $output = '<ul>' . drupal_render($variables['tree']) . '</ul>';
  }

  return $output;
}
